require File.dirname(__FILE__) + '/../test_helper'
require 'function_controller'

# Re-raise errors caught by the controller.
class FunctionController; def rescue_action(e) raise e end; end

class FunctionControllerTest < ActionController::TestCase
  def setup
    @controller = FunctionController.new
    @request    = ActionController::TestRequest.new
    @response   = ActionController::TestResponse.new
  end

  # Replace this with your real tests.
  def test_truth
    assert true
  end
end
